# pycounts_gcoronel

Calculate word counts in a text file as described in the Python Packages book!

## Installation
I haven't tried this way:
```bash
$ pip install pycounts_gcoronel
```
But I tried this following the book:
```bash
$ conda activate pycounts_gcoronel
```
and then
```bash
$ poetry install
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`pycounts_gcoronel` was created by Gabriel Coronel. It is licensed under the terms of the MIT license.

## Credits

`pycounts_gcoronel` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
